# PyWebHost
Python-based All-in-One Webserver,Handles both `Websocket` and oridnary HTTP Requests

## Demo
The included demo program,`demo.py`,serves as both a `Websocket` server and a HTTP File server.

`usage:	demo.py [address] [port]`

## Usage
You got the demo,and that's pretty much enough lol